remove: simplify help
authorMatt Mackall <mpm@selenic.com>
Fri, 16 Sep 2011 17:41:36 -0500
changeset 15114 d1bbabf7d35d
parent 15113 b55129f7f039
child 15115 c84b3f42d5ae
remove: simplify help - move the obscure parts into the verbose help - drop confusing references to "remove from repository" / "not remove from history" - add mention of hg forget
mercurial/commands.py
--- a/mercurial/commands.py	Fri Sep 16 17:08:18 2011 -0500
+++ b/mercurial/commands.py	Fri Sep 16 17:41:36 2011 -0500
@@ -4081,19 +4081,24 @@
 def remove(ui, repo, *pats, **opts):
     """remove the specified files on the next commit
 
-    Schedule the indicated files for removal from the repository.
-
-    This only removes files from the current branch, not from the
-    entire project history. -A/--after can be used to remove only
-    files that have already been deleted, -f/--force can be used to
-    force deletion, and -Af can be used to remove files from the next
-    revision without deleting them from the working directory.
-
-    The following table details the behavior of remove for different
-    file states (columns) and option combinations (rows). The file
-    states are Added [A], Clean [C], Modified [M] and Missing [!] (as
-    reported by :hg:`status`). The actions are Warn, Remove (from
-    branch) and Delete (from disk):
+    Schedule the indicated files for removal from the current branch.
+
+    This command schedules the files to be removed at the next commit.
+    To undo a remove before that, see :hg:`revert`. To undo added
+    files, see :hg:`forget`.
+
+    .. container:: verbose
+
+      -A/--after can be used to remove only files that have already
+      been deleted, -f/--force can be used to force deletion, and -Af
+      can be used to remove files from the next revision without
+      deleting them from the working directory.
+
+      The following table details the behavior of remove for different
+      file states (columns) and option combinations (rows). The file
+      states are Added [A], Clean [C], Modified [M] and Missing [!]
+      (as reported by :hg:`status`). The actions are Warn, Remove
+      (from branch) and Delete (from disk):
 
       ======= == == == ==
               A  C  M  !
@@ -4104,11 +4109,8 @@
       -Af     R  R  R  R
       ======= == == == ==
 
-    Note that remove never deletes files in Added [A] state from the
-    working directory, not even if option --force is specified.
-
-    This command schedules the files to be removed at the next commit.
-    To undo a remove before that, see :hg:`revert`.
+      Note that remove never deletes files in Added [A] state from the
+      working directory, not even if option --force is specified.
 
     Returns 0 on success, 1 if any warnings encountered.
     """